summaryrefslogtreecommitdiff
path: root/gtk/gtkrecentmanager.c
diff options
context:
space:
mode:
authorEmmanuele Bassi <ebassi@gnome.org>2006-05-22 17:02:54 +0000
committerEmmanuele Bassi <ebassi@src.gnome.org>2006-05-22 17:02:54 +0000
commit4636fa7efe134441db9b48a5ba029a99cb82fcf8 (patch)
treeaba95ff7a111a6c9ff1df471c5eb306120f07922 /gtk/gtkrecentmanager.c
parent58aa5c5e8fb8848d8cf7792546f8a1bf94a4b5a5 (diff)
downloadgtk+-4636fa7efe134441db9b48a5ba029a99cb82fcf8.tar.gz
Don't mask "time" with the "time" argument.
2006-05-22 Emmanuele Bassi <ebassi@gnome.org> * gtk/gtkrecentmanager.h: * gtk/gtkrecentmanager.c (gtk_recent_info_get_application_info): Don't mask "time" with the "time" argument.
Diffstat (limited to 'gtk/gtkrecentmanager.c')
-rw-r--r--gtk/gtkrecentmanager.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/gtk/gtkrecentmanager.c b/gtk/gtkrecentmanager.c
index 67e0617a8c..e047f29bc2 100644
--- a/gtk/gtkrecentmanager.c
+++ b/gtk/gtkrecentmanager.c
@@ -1743,7 +1743,7 @@ recent_app_info_free (RecentAppInfo *app_info)
* @app_name: the name of the application that has registered this item
* @app_exec: return location for the string containing the command line
* @count: return location for the number of times this item was registered
* @time: return location for the timestamp this item was last registered
* for this application
*
* Gets the data regarding the application that has registered the resource
@@ -1763,7 +1763,7 @@ gtk_recent_info_get_application_info (GtkRecentInfo *info,
const gchar *app_name,
gchar **app_exec,
guint *count,
- time_t *time)
+ time_t *time_)
{
RecentAppInfo *ai;
@@ -1788,7 +1788,7 @@ gtk_recent_info_get_application_info (GtkRecentInfo *info,
*count = ai->count;
if (time)
- *time = ai->stamp;
+ *time_ = ai->stamp;
return TRUE;
}
@@ -1743,7 +1743,7 @@ recent_app_info_free (RecentAppInfo *app_info)
* @app_exec: return location for the string containing the command line
* @count: return location for the number of times this item was registered
- * @time: return location for the timestamp this item was last registered
+ * @time_: return location for the timestamp this item was last registered
* for this application
*